<?php

class SJqueryBanner extends CWidget
{
	//***************************************************************************
	// Configuration
	//***************************************************************************

	/**
	* Options for each jQuery  widget
	*/

	public $containerId;
	public $containerClass;
	public $bannerContents;

	public $width  = 940;
	public $height = 220;
	public $button_width= 24;
	public $button_height= 24;
	public $button_margin=4;
	public $delay=6000;
	public $transition="random";
	public $transition_speed=800;
	public $block_size=75;
	public $vert_size=55;
	public $horz_size=50;
	public $cpanel_align="BR";
	public $auto_start=true;
	public $display_thumbs=true;
	public $display_dbuttons=true;
	public $display_playbutton=true;
	public $display_tooltip=true;
	public $display_numbers=true;
	public $display_timer=true;
	public $mouseover_pause=false;
	public $cpanel_mouseover=false;
	public $text_mouseover=false;
	public $shuffle=true;
	public $text_effect="fade";
	public $block_delay=25;
	public $vstripe_delay=75;
	public $hstripe_delay=150;


	//***************************************************************************
	// Getters and Setters
	//***************************************************************************



	//***************************************************************************
	// Internal properties
	//***************************************************************************

	/**
	* The base URL for the published assets
	*
	* @var string
	*/
	protected $baseUrl = '';

	/**
	* The CClientScript instance
	*
	* @var CClientScript
	*/
	protected $clientScript = null;


	//***************************************************************************
	// Utilities
	//***************************************************************************

	/**
	* Publishes the assets
	*/
	public function publishAssets()
	{
		$dir = dirname(__FILE__).DIRECTORY_SEPARATOR.'resources';
		$this->baseUrl = Yii::app()->getAssetManager()->publish($dir);
	}

	/**
	* Registers the external javascript files
	*/
	public function registerClientScripts()
	{
		if ($this->baseUrl === '')
			throw new CException(Yii::t('app', 'baseUrl must be set. This is done automatically by calling publishAssets()'));

		$this->clientScript = Yii::app()->getClientScript();

		$this->clientScript->registerCoreScript('jquery');

		$this->clientScript->registerScriptFile($this->baseUrl.'/js/jquery.wt-rotator1.js');

		$this->clientScript->registerCssFile($this->baseUrl.'/css/wt-rotator1.css');
	}


	/**
	* Generates the options for the widget
	*
	* @return string
	*/
	protected function createOptions()
	{
		$options = array();

		$options['auto_start']		= $this->auto_start?'true':'false';
		$options['display_thumbs']	= $this->display_thumbs?'true':'false';
		$options['display_dbuttons']	= $this->display_dbuttons?'true':'false';
		$options['display_playbutton']	= $this->display_playbutton?'true':'false';
		$options['display_tooltip']	= $this->display_tooltip?'true':'false';
		$options['display_numbers']	= $this->display_numbers?'true':'false';
		$options['display_timer']	= $this->display_timer?'true':'false';
		$options['mouseover_pause']	= $this->mouseover_pause?'true':'false';
		$options['cpanel_mouseover']	= $this->cpanel_mouseover?'true':'false';
		$options['text_mouseover']	= $this->text_mouseover?'true':'false';
		$options['shuffle']		= $this->shuffle?'true':'false';


		$options['width']		= $this->width;
		$options['height']		= $this->height;
		$options['button_width']	= $this->button_width;
		$options['button_height']	= $this->button_height;
		$options['button_margin']	= $this->button_margin;
		$options['delay']		= $this->delay;
		$options['transition']		= $this->transition;
		$options['transition_speed']	= $this->transition_speed;
		$options['block_size']		= $this->block_size;
		$options['vert_size']		= $this->vert_size;
		$options['horz_size']		= $this->horz_size;
		$options['cpanel_align']	= $this->cpanel_align;
		$options['text_effect']		= $this->text_effect;
		$options['block_delay']		= $this->block_delay;
		$options['vstripe_delay']	= $this->vstripe_delay;
		$options['hstripe_delay']	= $this->hstripe_delay;
		
		return $options;
	}


	/**
	* The javascript needed
	*/
	protected function createJsCode($options){
	$js =<<<EOP
	$(document).ready(
	function() {
		var \$container = $("#{$this->containerId}");
		\$container.wtRotator({
			width:{$options['width']},
			height:{$options['height']},
			button_width:{$options['button_width']},
			button_height:{$options['button_height']},
			button_margin:{$options['button_margin']},
			auto_start:{$options['auto_start']},
			delay:{$options['delay']},
			transition:"{$options['transition']}",
			transition_speed:{$options['transition_speed']},
			block_size:{$options['block_size']},
			vert_size:{$options['vert_size']},
			horz_size:{$options['horz_size']},
			cpanel_align:"{$options['cpanel_align']}",
			display_thumbs:{$options['display_thumbs']},
			display_dbuttons:{$options['display_dbuttons']},
			display_playbutton:{$options['display_playbutton']},
			display_tooltip:{$options['display_tooltip']},
			display_numbers:{$options['display_numbers']},
			display_timer:{$options['display_timer']},
			mouseover_pause:{$options['mouseover_pause']},
			cpanel_mouseover:{$options['cpanel_mouseover']},
			text_mouseover:{$options['text_mouseover']},
			text_effect:"{$options['text_effect']}",
			shuffle:{$options['shuffle']},
			block_delay:{$options['block_delay']},
			vstripe_delay:{$options['vstripe_delay']},
			hstripe_delay:{$options['hstripe_delay']}
		});
	});
EOP;
		return $js;
	}


	/**
	* Generates the needed html
	*/
	protected function createHtmlCode()
	{
		if($this->bannerContents):
		$html =<<<EOT
		<div id="{$this->containerId}" class="{$this->containerClass}">
			<div class="wt-rotator">
				<a href="#"></a>
				<div class="desc rounded"></div>
				<div class="preloader"></div>
				<div class="c-panel">
					<div class="buttons">
						<div class="prev-btn"></div>
						<div class="play-btn"></div>
						<div class="next-btn"></div>
					</div>

					<div class="thumbnails">
						<ul>
EOT;

						foreach($this->bannerContents as $banner):
							$html .='<li>';
							$html .= CHtml::link('', $banner['imageUrl'], array('title'=>$banner['linkTitle']));
							$html .= CHtml::link('', $banner['linkUrl'], array('target'=>$banner['linkTarget']));
							if(!empty($banner['bannerTitle'])):
								$html .= '<p style="left: 50px; top: 34px; width: 306px;">';
								$html .= '<span class="title">'. $banner['bannerTitle'] . '</span><br>';
								$html .= $banner['bannerDescription'];
								$html .= '</p>';
							endif;

							$html .='</li>';
						endforeach;

						$html.=<<<EOT
						</ul>
					</div>
				</div>
			</div>
		</div>
EOT;

		else:
		    $html = '';
		endif;

		return $html;
	}



	//***************************************************************************
	// Run
	//***************************************************************************

	/**
	* Run the widget
	*/
	public function run()
	{

		if(count($this->bannerContents) > 0):
			$this->publishAssets();
			$this->registerClientScripts();

			$options = $this->createOptions();
			$js      = $this->createJsCode($options);

			$this->clientScript->registerScript('SJqueryRotator',$js,CClientScript::POS_END);

			$html = $this->createHtmlCode();
		else:
			$html = '';
		endif;

		echo $html;
	}

}