<?php

class Banner extends BaseActiveRecord
{

	const SHOWATSITEHOME        = 1;
	const DONTSHOWATSITEHOME    = 0;
	const SHOWATCOMPANYHOME     = 1;
	const DONTSHOWATCOMPANYHOME = 0;

	public static function model($className=__CLASS__)
	{
		return parent::model($className);
	}

	public function tableName()
	{
		return 'Banner';
	}

	public function scopes(){
		return array(
			'own'=>array(
				'with'=>'company',
				'condition'=>'userId=:user',
				'params'=>array(':user'=>Yii::app()->user->getId())
			),

			//company MUST be active to the offer be published
			'published'=>array(
				//'join'=>'INNER JOIN Company ON Company.id = t.companyId AND Company.companyStatus =:sts LEFT OUTER JOIN Plan ON Company.planId = Plan.id',
				'join'=>'INNER JOIN Company ON Company.id = t.companyId AND Company.companyStatus =:sts',
				'condition'=>'CURDATE() BETWEEN bannerDateStart AND bannerDateFinish',
				'params'=>array(':sts'=>Company::STATUS_ONLINE)
			),

			'showAtSiteHome'=>array(
				'condition'=>'bannerShowAtSiteHome =:athome',
				'params'=>array(':athome'=>self::SHOWATSITEHOME)
			),
		    
			'showAtCompanyHome'=>array(
				'condition'=>'bannerShowAtCompanyHome =:athome',
				'params'=>array(':athome'=>self::SHOWATCOMPANYHOME)
			),

		);
	}


	public static function getBannerContents($companyId=null,$showAtCompanyHome=false,$showAtSiteHome=false,$filenamePrefix=''){
		$connection = Yii::app()->db;

		$sql = "SELECT  `t`.`id`,
				`t`.`bannerFileName`,
				`t`.`bannerTitle`,
				`t`.`bannerDescription`,
				`t`.`bannerLinkUrl`,
				`t`.`bannerLinkTarget` 
				FROM `Banner` `t`
				INNER JOIN Company ON (Company.id = t.companyId AND Company.companyStatus =:sts)
				WHERE (CURDATE() BETWEEN bannerDateStart AND bannerDateFinish) ";

		//company
		if(0 < $companyId):
			$sql .= " AND (Company.id =:cp1) ";
		endif;
		//showatcompanyhome
		if($showAtSiteHome):
			$sql .= " AND (bannerShowAtSiteHome =:ash) ";
		endif;
		//showatsitehome
		if($showAtCompanyHome):
			$sql .= " AND (bannerShowAtCompanyHome =:ach) ";
		endif;


		$command = $connection->createCommand($sql);

		//bind parameters
		$sts = Company::STATUS_ONLINE;
		$command->bindParam(':sts',$sts,PDO::PARAM_INT);
		
		if(0 < $companyId):
			$command->bindParam(':cp1',$companyId,PDO::PARAM_INT);
		endif;
		if($showAtSiteHome):
			$ash = self::SHOWATSITEHOME;
			$command->bindParam(':ash',$ash,PDO::PARAM_INT);
		endif;
		if($showAtCompanyHome):
			$ach = self::SHOWATCOMPANYHOME;
			$command->bindParam(':ach',$ach,PDO::PARAM_INT);
		endif;


		$dataReader = $command->query();

		//creates banner contents

		if(0 < $dataReader->rowCount):

			foreach($dataReader as $item):
				$bannerContents[] =
				array(
					'imageUrl'=>Yii::app()->params['imagesSubdomain'] . 'banners/'. $item['id'] .'/' . $filenamePrefix . $item['bannerFileName'],
					'linkTitle'=>$item['bannerTitle'],
					'linkUrl'=>$item['bannerLinkUrl'],
					'linkTarget'=>$item['bannerLinkTarget'],
					'bannerTitle'=>$item['bannerTitle'],
					'bannerDescription'=>$item['bannerDescription']
				);
			endforeach;

			return $bannerContents;
		endif;

		return false;
	}

	/*
	public static function getBannerContents($companyId=null,$showAtCompanyHome=false,$showAtSiteHome=false,$filenamePrefix=''){

		//apply criteria
		$criteria = new CDbCriteria();
		if(0 < $companyId):
			$criteria->addCondition('companyId =:cp1');
			$criteria->params = array(':cp1'=>$companyId);
		endif;

		//apply scopes
		$scopes   = array();
		$scopes[] = 'published';

		if($showAtSiteHome)
			$scopes[] = 'showAtSiteHome';

		if($showAtCompanyHome)
			$scopes[] = 'showAtCompanyHome';

		//get data
		$dataProvider=new EActiveDataProvider('Banner',
			array(
				'scopes'=>$scopes,
				'pagination'=>false,
				'criteria'=>$criteria
			)
		);


		//creates banner contents
		$bannerContents = array();
		$data = $dataProvider->getData();

		if(0 < count($data)):

			foreach($data as $i=>$item):
				$bannerContents[] =
				array(
					'imageUrl'=>Yii::app()->baseUrl.'/images/banners/'. $item->id .'/' . $filenamePrefix . $item->bannerFileName,
					'linkTitle'=>$item->bannerTitle,
					'linkUrl'=>$item->bannerLinkUrl,
					'linkTarget'=>$item->bannerLinkTarget,
					'bannerTitle'=>$item->bannerTitle,
					'bannerDescription'=>$item->bannerDescription
				);
			endforeach;

			return $bannerContents;
		endif;

		return false;
	}*/



	public function rules()
	{
		return array(
			array('bannerName, bannerDateStart, bannerDateFinish, companyId', 'required'),
			array('bannerShowAtSiteHome, bannerShowAtCompanyHome, companyId', 'numerical', 'integerOnly'=>true),
			array('bannerName, bannerFileName', 'length', 'max'=>40),
			array('bannerTitle', 'length', 'max'=>30),
			array('bannerDescription', 'length', 'max'=>100),
			array('bannerLinkUrl', 'length', 'max'=>255),
			array('bannerLinkTarget', 'length', 'max'=>10),
			array('bannerLinkUrl','url','allowEmpty'=>true),
			array('id, bannerName, bannerDateStart, bannerDateFinish, bannerFileName, bannerTitle, bannerDescription, bannerLinkUrl, bannerLinkTarget, bannerShowAtSiteHome, bannerShowAtCompanyHome, companyId', 'safe', 'on'=>'search'),
		);
	}

	public function relations()
	{
		return array(
			'company' => array(self::BELONGS_TO, 'Company', 'companyId'),
		);
	}

	public function behaviors()
	{
		return CMap::mergeArray(
			array('CAdvancedArBehavior',array('class' => 'ext.CAdvancedArBehavior')),

			parent::behaviors()
		);
		//return array('CAdvancedArBehavior',
//				array('class' => 'ext.CAdvancedArBehavior')
				//);
	}

	public function attributeLabels()
	{
		return array(
			'id' => 'Id',
			'bannerName' => 'Nome',
			'bannerDateStart' => 'Início Publicação',
			'bannerDateFinish' => 'Final Publicação',
			'bannerFileName' => 'Arquivo',
			'bannerTitle' => 'Título',
			'bannerDescription' => 'Descrição Adicional',
			'bannerLinkUrl' => 'URL do link',
			'bannerLinkTarget' => 'Abrir o link',
			'bannerShowAtSiteHome' => 'Exibe no home do Ofertagora',
			'bannerShowAtCompanyHome' => 'Exibe na página do anunciante',
			'companyId' => 'Empresa',
		);
	}

	public function search()
	{
		$criteria=new CDbCriteria;

		$criteria->compare('id',$this->id);

		$criteria->compare('bannerName',$this->bannerName,true);

		$criteria->compare('bannerDateStart',$this->bannerDateStart,true);

		$criteria->compare('bannerDateFinish',$this->bannerDateFinish,true);

		$criteria->compare('bannerFileName',$this->bannerFileName,true);

		$criteria->compare('bannerTitle',$this->bannerTitle,true);

		$criteria->compare('bannerDescription',$this->bannerDescription,true);

		$criteria->compare('bannerLinkUrl',$this->bannerLinkUrl,true);

		$criteria->compare('bannerLinkTarget',$this->bannerLinkTarget,true);

		$criteria->compare('bannerShowAtSiteHome',$this->bannerShowAtSiteHome);

		$criteria->compare('bannerShowAtCompanyHome',$this->bannerShowAtCompanyHome);

		//$criteria->compare('companyId',$this->companyId);

		$criteria->with = array('company');
		if (!Yii::app()->user->getHasRole('SiteAdmin')):
			$criteria->compare('company.userId',Yii::app()->user->getId());
		endif;

		return new CActiveDataProvider(get_class($this), array(
			'criteria'=>$criteria,
		));
	}

	public function beforeDelete(){
		//delete images dir for this offer
		$dirName = dirname(Yii::app()->getBasePath()).DIRECTORY_SEPARATOR.'images'.DIRECTORY_SEPARATOR.'banners'.DIRECTORY_SEPARATOR .$this->id;

		SFileHelper::deleteDir($dirName);

		return parent::beforeDelete();
	}

}
